% CASA book figures 10.7 and 10.8
%
% Guy Brown, University of Sheffield 
%
% This software is provided "as is" without warranty of any kind

addpath(fullfile('..','library'));

close all;

lowcf=80;
highcf=4500;
numchannels=64;
fs=20000;

% channel selection stuff

x=load('doublevowels/ar.zero.er.four.sig');
x=resample(x,2,1); % requires the signal processing toolbox
bm=gammatonebank(x',lowcf,highcf,numchannels,fs);
bm(bm<0)=0;
c=runningacg(bm,1000,2000,300);
selected=c(:,201)./c(:,1)>0.8;
s1=sum(c(selected,:));
s1=s1/max(s1);
plotsummary(s1,'recovered ar',201);
s2=sum(c(~selected,:));
s2=s2/max(s2);
plotsummary(s2,'recovered er',159);

% cancellation stuff

disp('the next bit is very inefficient and takes some time ...');

% cancel the /ar/

cn=cancellation(bm,200);
c=runningacg(cn,1000,2000,300);
s1=sum(c); s1=s1/max(s1);
plotsummary(s1,'cancelled at 100Hz',159);

% cancel the /er/

cn=cancellation(bm,158.7401);
c=runningacg(cn,1000,2000,300);
s1=sum(c); s1=s1/max(s1);
plotsummary(s1,'cancelled at 126Hz',200);

disp('phew, the next bit is quicker ...');

% other diagrams

x=load('doublevowels/ar.zero.er.zero.sig');
s=summaryacg(x,lowcf,highcf,numchannels,fs);
plotsummary(s,'ar zero er zero',201);

x=load('doublevowels/ar.zero.er.one.sig');
s=summaryacg(x,lowcf,highcf,numchannels,fs);
plotsummary(s,'ar zero er one',201,189);

x=load('doublevowels/ar.zero.er.two.sig');
s=summaryacg(x,lowcf,highcf,numchannels,fs);
plotsummary(s,'ar zero er two',201,179);

x=load('doublevowels/ar.zero.er.four.sig');
s=summaryacg(x,lowcf,highcf,numchannels,fs);
plotsummary(s,'ar zero er four',201,159);

x=load('singlevowels/ar.zero.sig');
s=summaryacg(x,lowcf,highcf,numchannels,fs);
plotsummary(s,'ar zero',201);

x=load('singlevowels/er.four.sig');
s=summaryacg(x,lowcf,highcf,numchannels,fs);
plotsummary(s,'er two',159);

disp('done');
