function [bm,env,instf]=gammatone(x,fs,cf)

% [bm,env,instf] = gammatone(x,fs,cf)
%
% Implements the 4th order gammatone filter using the approach
% described in Martin Cooke's PhD thesis (impulse invariant transform)
%
% Guy Brown, University of Sheffield 
% Adapted from code written by Martin Cooke
%
% This software is provided "as is" without warranty of any kind
%
% Inputs:
%
% x  : input signal
% fs : sample rate (Hz)
% cf : center frequency (Hz)
%
% Outputs:
%
% bm    : simulated basilar membrane displacement
% env   : instantaneous envelope
% instf : instantaneous frequency

wcf=2*pi*cf;	 	        % radian frequency
tpt=(2*pi)/fs;
bw=erb(cf)*bwcorrection;	% bandwidth
a=exp(-bw*tpt);
gain=((bw*tpt)^4)/6; 	     	% based on integral of impulse response

kT=[0:length(x)-1]/fs;

q=exp(j*(-wcf*kT)).*x;                           % shift down to d.c.
p=filter([1 0],[1 -4*a 6*a^2 -4*a^3 a^4],q);        % filter: part 1
u=filter([1 4*a 4*a^2 0],[1 0],p);                  % filter: part 2
bm=gain*real(exp(j*wcf*kT).*u);	                    % shift up in frequency

if nargout > 1                                      % instantaneous envelope  
  env = gain*abs(u);
  if nargout == 3                                   % instantaneous frequency
    instf=real(cf+[diff(unwrap(angle(u))) 0]./tpt);
  end
end 
